infunction [mu, sigma] = kalman1d( mu_last, sigma_last, u, z )
% 1-D Kalman filter example.

    % Motion update parameters
    a = 1;
    b = 1;
    r = 0.25; % Variance

    % Measurement update parameters
    c = 1;
    q = 1.0; % Variance

    % Application of the Kalman Filter
    mu_bar = a * mu_last + b * u;
    sigma_bar = a^2 * sigma_last + r;
    k = (sigma_bar * c ) / (c^2 * sigma_bar + q);
    mu = mu_bar + k * (z - c * mu_bar);
    sigma = (1 - k * c) * sigma_bar;

    % Plot
    t = -1:0.05:8;
    hold on;    
    plot(t, normpdf(t, mu_bar, sigma_bar), 'b-'); 
    legend('Prediction');
    pause;
    plot(t, normpdf(t, z, q), 'g-');
    legend('Prediction', 'Measurement');
    pause;
    plot(t, normpdf(t, mu, sigma), 'r-', 'LineWidth', 2);
    legend('Prediction', 'Measurement', 'New Belief');
