function [Mu, Sigma] = kalman2d( Mu_last, Sigma_last, u, z )
% 2-D Kalman Filter example.  Modelling the position of a 1-D robot together
% with its velocity.  The sensor is a position sensor.

    % Covariance matrix of system update equation
    R = [0.2 0.05 ; 0.05 0.1];

    % Variance of position sensor
    Q = 0.5;
    
    % Other parameters
    mass = 1;
    deltaT = 1;

    A = [1 deltaT ; 0 1];
    B = [0 ; deltaT / mass];
    C = [1 0];

    % Line 2 of KF
    MuBar = A * Mu_last + B * u

    % Line 3 of KF
    SigmaBar =  A * Sigma_last * A' + R

    % Line 4 of Kf
    K = SigmaBar * C' * inv(C * SigmaBar * C' + Q)

    % Line 5 of KF
    Mu = MuBar + K * (z - C*MuBar)

    % Line 6 of KF
    Sigma = (eye(2,2) - K*C) * SigmaBar

    % Plot mean position of robot
    plot(Mu(1), Mu(2), 'k*');
    xlabel('Position')
    ylabel('Velocity')

    % Plot error ellipse
    error_ellipse('C', Sigma, 'mu', Mu, 'conf', 0.5);
